@@ -8,8 +8,8 @@ require "bundler/cli/doctor"
 RSpec.describe "bundle doctor" do
   before(:each) do
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gem "rack"
+      source "https://gem.repo1"
+      gem "myrack"
     G
 
     @stdout = StringIO.new
@@ -38,6 +38,11 @@ RSpec.describe "bundle doctor" do
       allow(stat).to receive(:uid) { Process.uid }
       allow(File).to receive(:writable?).with(unwritable_file) { true }
       allow(File).to receive(:readable?).with(unwritable_file) { true }
+
+      # The following lines are for `Gem::PathSupport#initialize`.
+      allow(File).to receive(:exist?).with(Gem.default_dir)
+      allow(File).to receive(:writable?).with(Gem.default_dir)
+      allow(File).to receive(:writable?).with(File.expand_path("..", Gem.default_dir))
     end
 
     it "exits with no message if the installed gem has no C extensions" do
@@ -47,7 +52,7 @@ RSpec.describe "bundle doctor" do
 
     it "exits with no message if the installed gem's C extension dylib breakage is fine" do
       doctor = Bundler::CLI::Doctor.new({})
-      expect(doctor).to receive(:bundles_for_gem).exactly(2).times.and_return ["/path/to/rack/rack.bundle"]
+      expect(doctor).to receive(:bundles_for_gem).exactly(2).times.and_return ["/path/to/myrack/myrack.bundle"]
       expect(doctor).to receive(:dylibs).exactly(2).times.and_return ["/usr/lib/libSystem.dylib"]
       allow(Fiddle).to receive(:dlopen).with("/usr/lib/libSystem.dylib").and_return(true)
       expect { doctor.run }.not_to raise_error
@@ -56,13 +61,13 @@ RSpec.describe "bundle doctor" do
 
     it "exits with a message if one of the linked libraries is missing" do
       doctor = Bundler::CLI::Doctor.new({})
-      expect(doctor).to receive(:bundles_for_gem).exactly(2).times.and_return ["/path/to/rack/rack.bundle"]
+      expect(doctor).to receive(:bundles_for_gem).exactly(2).times.and_return ["/path/to/myrack/myrack.bundle"]
       expect(doctor).to receive(:dylibs).exactly(2).times.and_return ["/usr/local/opt/icu4c/lib/libicui18n.57.1.dylib"]
       allow(Fiddle).to receive(:dlopen).with("/usr/local/opt/icu4c/lib/libicui18n.57.1.dylib").and_raise(Fiddle::DLError)
-      expect { doctor.run }.to raise_error(Bundler::ProductionError, strip_whitespace(<<-E).strip), @stdout.string
+      expect { doctor.run }.to raise_error(Bundler::ProductionError, <<~E.strip), @stdout.string
         The following gems are missing OS dependencies:
          * bundler: /usr/local/opt/icu4c/lib/libicui18n.57.1.dylib
-         * rack: /usr/local/opt/icu4c/lib/libicui18n.57.1.dylib
+         * myrack: /usr/local/opt/icu4c/lib/libicui18n.57.1.dylib
       E
     end
   end
