@@ -10,11 +10,9 @@ RSpec.describe "bundle install from an existing gemspec" do
 
   let(:x64_mingw_archs) do
     if RUBY_PLATFORM == "x64-mingw-ucrt"
-      if Gem.rubygems_version >= Gem::Version.new("3.2.28")
-        ["x64-mingw-ucrt", "x64-mingw32"]
-      else
-        ["x64-mingw32", "x64-unknown"]
-      end
+
+      ["x64-mingw-ucrt", "x64-mingw32"]
+
     else
       ["x64-mingw32"]
     end
@@ -28,36 +26,46 @@ RSpec.describe "bundle install from an existing gemspec" do
     x64_mingw_archs.join("\n  ")
   end
 
+  def x64_mingw_checksums(checksums)
+    x64_mingw_archs.each do |arch|
+      if arch == "x64-mingw-ucrt"
+        checksums.no_checksum "platform_specific", "1.0", arch
+      else
+        checksums.checksum gem_repo2, "platform_specific", "1.0", arch
+      end
+    end
+  end
+
   it "should install runtime and development dependencies" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
-    expect(the_bundle).to include_gems "bar-dev 1.0.0", :groups => :development
+    expect(the_bundle).to include_gems "bar-dev 1.0.0", groups: :development
   end
 
   it "that is hidden should install runtime and development dependencies" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
-    FileUtils.mv tmp.join("foo", "foo.gemspec"), tmp.join("foo", ".gemspec")
+    FileUtils.mv tmp("foo", "foo.gemspec"), tmp("foo", ".gemspec")
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
-    expect(the_bundle).to include_gems "bar-dev 1.0.0", :groups => :development
+    expect(the_bundle).to include_gems "bar-dev 1.0.0", groups: :development
   end
 
   it "should handle a list of requirements" do
@@ -66,151 +74,151 @@ RSpec.describe "bundle install from an existing gemspec" do
       build_gem "baz", "1.1"
     end
 
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "baz", ">= 1.0", "< 1.1"
     end
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "baz 1.0"
   end
 
   it "should raise if there are no gemspecs available" do
-    build_lib("foo", :path => tmp.join("foo"), :gemspec => false)
+    build_lib("foo", path: tmp("foo"), gemspec: false)
 
-    install_gemfile <<-G, :raise_on_error => false
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+    install_gemfile <<-G, raise_on_error: false
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
-    expect(err).to match(/There are no gemspecs at #{tmp.join("foo")}/)
+    expect(err).to match(/There are no gemspecs at #{tmp("foo")}/)
   end
 
   it "should raise if there are too many gemspecs available" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", build_spec("foo", "4.0").first.to_ruby)
     end
 
-    install_gemfile <<-G, :raise_on_error => false
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+    install_gemfile <<-G, raise_on_error: false
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
-    expect(err).to match(/There are multiple gemspecs at #{tmp.join("foo")}/)
+    expect(err).to match(/There are multiple gemspecs at #{tmp("foo")}/)
   end
 
   it "should pick a specific gemspec" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", "")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
 
     install_gemfile(<<-G)
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
-    expect(the_bundle).to include_gems "bar-dev 1.0.0", :groups => :development
+    expect(the_bundle).to include_gems "bar-dev 1.0.0", groups: :development
   end
 
   it "should use a specific group for development dependencies" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", "")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
 
     install_gemfile(<<-G)
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo', :development_group => :dev
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}', :name => 'foo', :development_group => :dev
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
-    expect(the_bundle).not_to include_gems "bar-dev 1.0.0", :groups => :development
-    expect(the_bundle).to include_gems "bar-dev 1.0.0", :groups => :dev
+    expect(the_bundle).not_to include_gems "bar-dev 1.0.0", groups: :development
+    expect(the_bundle).to include_gems "bar-dev 1.0.0", groups: :dev
   end
 
   it "should match a lockfile even if the gemspec defines development dependencies" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
-      s.write("Gemfile", "source '#{file_uri_for(gem_repo1)}'\ngemspec")
+    build_lib("foo", path: tmp("foo")) do |s|
+      s.write("Gemfile", "source 'https://gem.repo1'\ngemspec")
       s.add_dependency "actionpack", "=2.3.2"
-      s.add_development_dependency "rake", "=13.0.1"
+      s.add_development_dependency "rake", rake_version
     end
 
-    bundle "install", :dir => tmp.join("foo")
+    bundle "install", dir: tmp("foo"), artifice: "compact_index", env: { "BUNDLER_SPEC_GEM_REPO" => gem_repo1.to_s }
     # This should really be able to rely on $stderr, but, it's not written
     # right, so we can't. In fact, this is a bug negation test, and so it'll
     # ghost pass in future, and will only catch a regression if the message
     # doesn't change. Exit codes should be used correctly (they can be more
     # than just 0 and 1).
     bundle "config set --local deployment true"
-    output = bundle("install", :dir => tmp.join("foo"))
+    output = bundle("install", dir: tmp("foo"), artifice: "compact_index", env: { "BUNDLER_SPEC_GEM_REPO" => gem_repo1.to_s })
     expect(output).not_to match(/You have added to the Gemfile/)
     expect(output).not_to match(/You have deleted from the Gemfile/)
     expect(output).not_to match(/the lockfile can't be updated because frozen mode is set/)
   end
 
   it "should match a lockfile without needing to re-resolve" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
-      s.add_dependency "rack"
+    build_lib("foo", path: tmp("foo")) do |s|
+      s.add_dependency "myrack"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo1"
+      gemspec :path => '#{tmp("foo")}'
     G
 
-    bundle "install", :verbose => true
+    bundle "install", verbose: true
 
     message = "Found no changes, using resolution from the lockfile"
     expect(out.scan(message).size).to eq(1)
   end
 
   it "should match a lockfile without needing to re-resolve with development dependencies" do
-    simulate_platform java
+    simulate_platform java do
+      build_lib("foo", path: tmp("foo")) do |s|
+        s.add_dependency "myrack"
+        s.add_development_dependency "thin"
+      end
 
-    build_lib("foo", :path => tmp.join("foo")) do |s|
-      s.add_dependency "rack"
-      s.add_development_dependency "thin"
+      install_gemfile <<-G
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}'
+      G
+
+      bundle "install", verbose: true
+
+      message = "Found no changes, using resolution from the lockfile"
+      expect(out.scan(message).size).to eq(1)
     end
-
-    install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gemspec :path => '#{tmp.join("foo")}'
-    G
-
-    bundle "install", :verbose => true
-
-    message = "Found no changes, using resolution from the lockfile"
-    expect(out.scan(message).size).to eq(1)
   end
 
   it "should match a lockfile on non-ruby platforms with a transitive platform dependency", :jruby_only do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.add_dependency "platform_specific"
     end
 
-    system_gems "platform_specific-1.0-java", :path => default_bundle_path
+    system_gems "platform_specific-1.0-java", path: default_bundle_path
 
     install_gemfile <<-G
-      gemspec :path => '#{tmp.join("foo")}'
+      gemspec :path => '#{tmp("foo")}'
     G
 
-    bundle "update --bundler", :artifice => "compact_index", :verbose => true
-    expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 JAVA"
+    bundle "update --bundler", artifice: "compact_index", verbose: true
+    expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 java"
   end
 
   it "should evaluate the gemspec in its directory" do
-    build_lib("foo", :path => tmp.join("foo"))
-    File.open(tmp.join("foo/foo.gemspec"), "w") do |s|
-      s.write "raise 'ahh' unless Dir.pwd == '#{tmp.join("foo")}'"
+    build_lib("foo", path: tmp("foo"))
+    File.open(tmp("foo/foo.gemspec"), "w") do |s|
+      s.write "raise 'ahh' unless Dir.pwd == '#{tmp("foo")}'"
     end
 
-    install_gemfile <<-G, :raise_on_error => false
-      gemspec :path => '#{tmp.join("foo")}'
+    install_gemfile <<-G, raise_on_error: false
+      gemspec :path => '#{tmp("foo")}'
     G
     expect(last_command.stdboth).not_to include("ahh")
   end
@@ -221,16 +229,16 @@ RSpec.describe "bundle install from an existing gemspec" do
     #
     # issue was caused by rubygems having an unresolved gem during a require,
     # so emulate that
-    system_gems %w[rack-1.0.0 rack-0.9.1 rack-obama-1.0]
+    system_gems %w[myrack-1.0.0 myrack-0.9.1 myrack-obama-1.0]
 
-    build_lib("foo", :path => bundled_app)
+    build_lib("foo", path: bundled_app)
     gemspec = bundled_app("foo.gemspec").read
     bundled_app("foo.gemspec").open("w") do |f|
-      f.write "#{gemspec.strip}.tap { gem 'rack-obama'; require 'rack/obama' }"
+      f.write "#{gemspec.strip}.tap { gem 'myrack-obama'; require 'myrack/obama' }"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gemspec
     G
 
@@ -238,26 +246,26 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "allows conflicts" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.version = "1.0.0"
       s.add_dependency "bar", "= 1.0.0"
     end
-    build_gem "deps", :to_bundle => true do |s|
+    build_gem "deps", to_bundle: true do |s|
       s.add_dependency "foo", "= 0.0.1"
     end
-    build_gem "foo", "0.0.1", :to_bundle => true
+    build_gem "foo", "0.0.1", to_bundle: true
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
+      source "https://gem.repo2"
       gem "deps"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "foo 1.0.0"
   end
 
   it "does not break Gem.finish_resolve with conflicts" do
-    build_lib("foo", :path => tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.version = "1.0.0"
       s.add_dependency "bar", "= 1.0.0"
     end
@@ -269,9 +277,9 @@ RSpec.describe "bundle install from an existing gemspec" do
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
+      source "https://gem.repo2"
       gem "deps"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "foo 1.0.0"
@@ -281,14 +289,14 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "handles downgrades" do
-    build_lib "omg", "2.0", :path => lib_path("omg")
+    build_lib "omg", "2.0", path: lib_path("omg")
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gemspec :path => "#{lib_path("omg")}"
     G
 
-    build_lib "omg", "1.0", :path => lib_path("omg")
+    build_lib "omg", "1.0", path: lib_path("omg")
 
     bundle :install
 
@@ -298,23 +306,23 @@ RSpec.describe "bundle install from an existing gemspec" do
   context "in deployment mode" do
     context "when the lockfile was not updated after a change to the gemspec's dependencies" do
       it "reports that installation failed" do
-        build_lib "cocoapods", :path => bundled_app do |s|
+        build_lib "cocoapods", path: bundled_app do |s|
           s.add_dependency "activesupport", ">= 1"
         end
 
         install_gemfile <<-G
-          source "#{file_uri_for(gem_repo1)}"
+          source "https://gem.repo1"
           gemspec
         G
 
         expect(the_bundle).to include_gems("cocoapods 1.0", "activesupport 2.3.5")
 
-        build_lib "cocoapods", :path => bundled_app do |s|
+        build_lib "cocoapods", path: bundled_app do |s|
           s.add_dependency "activesupport", ">= 1.0.1"
         end
 
         bundle "config set --local deployment true"
-        bundle :install, :raise_on_error => false
+        bundle :install, raise_on_error: false
 
         expect(err).to include("changed")
       end
@@ -324,24 +332,24 @@ RSpec.describe "bundle install from an existing gemspec" do
   context "when child gemspecs conflict with a released gemspec" do
     before do
       # build the "parent" gem that depends on another gem in the same repo
-      build_lib "source_conflict", :path => bundled_app do |s|
-        s.add_dependency "rack_middleware"
+      build_lib "source_conflict", path: bundled_app do |s|
+        s.add_dependency "myrack_middleware"
       end
 
       # build the "child" gem that is the same version as a released gem, but
       # has completely different and conflicting dependency requirements
-      build_lib "rack_middleware", "1.0", :path => bundled_app("rack_middleware") do |s|
-        s.add_dependency "rack", "1.0" # anything other than 0.9.1
+      build_lib "myrack_middleware", "1.0", path: bundled_app("myrack_middleware") do |s|
+        s.add_dependency "myrack", "1.0" # anything other than 0.9.1
       end
     end
 
     it "should install the child gemspec's deps" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gemspec
       G
 
-      expect(the_bundle).to include_gems "rack 1.0"
+      expect(the_bundle).to include_gems "myrack 1.0"
     end
   end
 
@@ -349,8 +357,8 @@ RSpec.describe "bundle install from an existing gemspec" do
     let(:source_uri) { "http://localgemserver.test" }
 
     before do
-      build_lib("foo", :path => tmp.join("foo")) do |s|
-        s.add_dependency "rack", "=1.0.0"
+      build_lib("foo", path: tmp("foo")) do |s|
+        s.add_dependency "myrack", "=1.0.0"
       end
 
       gemfile <<-G
@@ -358,24 +366,28 @@ RSpec.describe "bundle install from an existing gemspec" do
         gemspec :path => "../foo"
       G
 
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "foo", "1.0"
+      end
+
       lockfile <<-L
         PATH
           remote: ../foo
           specs:
             foo (1.0)
-              rack (= 1.0.0)
+              myrack (= 1.0.0)
 
         GEM
           remote: #{source_uri}
           specs:
-            rack (1.0.0)
+            myrack (1.0.0)
 
         PLATFORMS
           #{generic_local_platform}
 
         DEPENDENCIES
           foo!
-
+        #{checksums}
         BUNDLED WITH
            #{Bundler::VERSION}
       L
@@ -384,9 +396,9 @@ RSpec.describe "bundle install from an existing gemspec" do
     context "using JRuby with explicit platform", :jruby_only do
       before do
         create_file(
-          tmp.join("foo", "foo-java.gemspec"),
+          tmp("foo", "foo-java.gemspec"),
           build_spec("foo", "1.0", "java") do
-            dep "rack", "=1.0.0"
+            dep "myrack", "=1.0.0"
             @spec.authors = "authors"
             @spec.summary = "summary"
           end.first.to_ruby
@@ -394,16 +406,16 @@ RSpec.describe "bundle install from an existing gemspec" do
       end
 
       it "should install" do
-        results = bundle "install", :artifice => "endpoint"
-        expect(results).to include("Installing rack 1.0.0")
-        expect(the_bundle).to include_gems "rack 1.0.0"
+        results = bundle "install", artifice: "endpoint"
+        expect(results).to include("Installing myrack 1.0.0")
+        expect(the_bundle).to include_gems "myrack 1.0.0"
       end
     end
 
     it "should install", :jruby do
-      results = bundle "install", :artifice => "endpoint"
-      expect(results).to include("Installing rack 1.0.0")
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      results = bundle "install", artifice: "endpoint"
+      expect(results).to include("Installing myrack 1.0.0")
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     context "bundled for multiple platforms" do
@@ -416,7 +428,7 @@ RSpec.describe "bundle install from an existing gemspec" do
           end
         end
 
-        build_lib "foo", :path => bundled_app do |s|
+        build_lib "foo", path: bundled_app do |s|
           if platform_specific_type == :runtime
             s.add_runtime_dependency dependency
           elsif platform_specific_type == :development
@@ -427,7 +439,7 @@ RSpec.describe "bundle install from an existing gemspec" do
         end
 
         gemfile <<-G
-          source "#{file_uri_for(gem_repo2)}"
+          source "https://gem.repo2"
           gemspec
         G
 
@@ -447,7 +459,15 @@ RSpec.describe "bundle install from an existing gemspec" do
 
         context "as a runtime dependency" do
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 ruby"
+
+            checksums = checksums_section_when_enabled do |c|
+              c.no_checksum "foo", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0", "java"
+              x64_mingw_checksums(c)
+            end
+
             expect(lockfile).to eq <<~L
               PATH
                 remote: .
@@ -456,7 +476,7 @@ RSpec.describe "bundle install from an existing gemspec" do
                     platform_specific
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   platform_specific (1.0)
                   platform_specific (1.0-java)
@@ -469,7 +489,7 @@ RSpec.describe "bundle install from an existing gemspec" do
 
               DEPENDENCIES
                 foo!
-
+              #{checksums}
               BUNDLED WITH
                  #{Bundler::VERSION}
             L
@@ -480,7 +500,15 @@ RSpec.describe "bundle install from an existing gemspec" do
           let(:platform_specific_type) { :development }
 
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 ruby"
+
+            checksums = checksums_section_when_enabled do |c|
+              c.no_checksum "foo", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0", "java"
+              x64_mingw_checksums(c)
+            end
+
             expect(lockfile).to eq <<~L
               PATH
                 remote: .
@@ -488,7 +516,7 @@ RSpec.describe "bundle install from an existing gemspec" do
                   foo (1.0)
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   platform_specific (1.0)
                   platform_specific (1.0-java)
@@ -502,7 +530,7 @@ RSpec.describe "bundle install from an existing gemspec" do
               DEPENDENCIES
                 foo!
                 platform_specific
-
+              #{checksums}
               BUNDLED WITH
                  #{Bundler::VERSION}
             L
@@ -514,7 +542,16 @@ RSpec.describe "bundle install from an existing gemspec" do
           let(:dependency) { "indirect_platform_specific" }
 
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "indirect_platform_specific 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "indirect_platform_specific 1.0", "platform_specific 1.0 ruby"
+
+            checksums = checksums_section_when_enabled do |c|
+              c.no_checksum "foo", "1.0"
+              c.checksum gem_repo2, "indirect_platform_specific", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0"
+              c.checksum gem_repo2, "platform_specific", "1.0", "java"
+              x64_mingw_checksums(c)
+            end
+
             expect(lockfile).to eq <<~L
               PATH
                 remote: .
@@ -522,7 +559,7 @@ RSpec.describe "bundle install from an existing gemspec" do
                   foo (1.0)
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   indirect_platform_specific (1.0)
                     platform_specific
@@ -538,7 +575,7 @@ RSpec.describe "bundle install from an existing gemspec" do
               DEPENDENCIES
                 foo!
                 indirect_platform_specific
-
+              #{checksums}
               BUNDLED WITH
                  #{Bundler::VERSION}
             L
@@ -550,10 +587,10 @@ RSpec.describe "bundle install from an existing gemspec" do
 
   context "with multiple platforms" do
     before do
-      build_lib("foo", :path => tmp.join("foo")) do |s|
+      build_lib("foo", path: tmp("foo")) do |s|
         s.version = "1.0.0"
-        s.add_development_dependency "rack"
-        s.write "foo-universal-java.gemspec", build_spec("foo", "1.0.0", "universal-java") {|sj| sj.runtime "rack", "1.0.0" }.first.to_ruby
+        s.add_development_dependency "myrack"
+        s.write "foo-universal-java.gemspec", build_spec("foo", "1.0.0", "universal-java") {|sj| sj.runtime "myrack", "1.0.0" }.first.to_ruby
       end
     end
 
@@ -561,11 +598,11 @@ RSpec.describe "bundle install from an existing gemspec" do
       bundle "config set --local force_ruby_platform true"
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}', :name => 'foo'
       G
 
-      expect(the_bundle).to include_gems "foo 1.0.0", "rack 1.0.0"
+      expect(the_bundle).to include_gems "foo 1.0.0", "myrack 1.0.0"
     end
 
     it "installs the ruby platform gemspec and skips dev deps with `without development` configured" do
@@ -573,18 +610,18 @@ RSpec.describe "bundle install from an existing gemspec" do
 
       bundle "config set --local without development"
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}', :name => 'foo'
       G
 
       expect(the_bundle).to include_gem "foo 1.0.0"
-      expect(the_bundle).not_to include_gem "rack"
+      expect(the_bundle).not_to include_gem "myrack"
     end
   end
 
   context "with multiple platforms and resolving for more specific platforms" do
     before do
-      build_lib("chef", :path => tmp.join("chef")) do |s|
+      build_lib("chef", path: tmp("chef")) do |s|
         s.version = "17.1.17"
         s.write "chef-universal-mingw32.gemspec", build_spec("chef", "17.1.17", "universal-mingw32") {|sw| sw.runtime "win32-api", "~> 1.5.3" }.first.to_ruby
       end
@@ -598,10 +635,16 @@ RSpec.describe "bundle install from an existing gemspec" do
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo4)}"
+        source "https://gem.repo4"
         gemspec :path => "../chef"
       G
 
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "chef", "17.1.17"
+        c.no_checksum "chef", "17.1.17", "universal-mingw32"
+        c.checksum gem_repo4, "win32-api", "1.5.3", "universal-mingw32"
+      end
+
       initial_lockfile = <<~L
         PATH
           remote: ../chef
@@ -611,7 +654,7 @@ RSpec.describe "bundle install from an existing gemspec" do
               win32-api (~> 1.5.3)
 
         GEM
-          remote: #{file_uri_for(gem_repo4)}/
+          remote: https://gem.repo4/
           specs:
             win32-api (1.5.3-universal-mingw32)
 
@@ -622,7 +665,7 @@ RSpec.describe "bundle install from an existing gemspec" do
 
         DEPENDENCIES
           chef!
-
+        #{checksums}
         BUNDLED WITH
            #{Bundler::VERSION}
       L
@@ -637,7 +680,7 @@ RSpec.describe "bundle install from an existing gemspec" do
 
   context "with multiple locked platforms" do
     before do
-      build_lib("activeadmin", :path => tmp.join("activeadmin")) do |s|
+      build_lib("activeadmin", path: tmp("activeadmin")) do |s|
         s.version = "2.9.0"
         s.add_dependency "railties", ">= 5.2", "< 6.2"
       end
@@ -651,7 +694,7 @@ RSpec.describe "bundle install from an existing gemspec" do
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo4)}"
+        source "https://gem.repo4"
         gemspec :path => "../activeadmin"
         gem "jruby-openssl", :platform => :jruby
       G
@@ -660,6 +703,12 @@ RSpec.describe "bundle install from an existing gemspec" do
     end
 
     it "does not remove the platform specific specs from the lockfile when re-resolving due to gemspec changes" do
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "activeadmin", "2.9.0"
+        c.checksum gem_repo4, "jruby-openssl", "0.10.7", "java"
+        c.checksum gem_repo4, "railties", "6.1.4"
+      end
+
       expect(lockfile).to eq <<~L
         PATH
           remote: ../activeadmin
@@ -668,7 +717,7 @@ RSpec.describe "bundle install from an existing gemspec" do
               railties (>= 5.2, < 6.2)
 
         GEM
-          remote: #{file_uri_for(gem_repo4)}/
+          remote: https://gem.repo4/
           specs:
             jruby-openssl (0.10.7-java)
             railties (6.1.4)
@@ -679,12 +728,12 @@ RSpec.describe "bundle install from an existing gemspec" do
         DEPENDENCIES
           activeadmin!
           jruby-openssl
-
+        #{checksums}
         BUNDLED WITH
            #{Bundler::VERSION}
       L
 
-      gemspec = tmp.join("activeadmin/activeadmin.gemspec")
+      gemspec = tmp("activeadmin/activeadmin.gemspec")
       File.write(gemspec, File.read(gemspec).sub(">= 5.2", ">= 6.0"))
 
       previous_lockfile = lockfile
