@@ -1,9 +1,11 @@
 # frozen_string_literal: true
 
-#--
+# rubocop:disable Style/AsciiComments
+
 # Copyright (C) 2004 Mauricio Julio Fernández Pradier
 # See LICENSE.txt for additional licensing information.
-#++
+
+# rubocop:enable Style/AsciiComments
 
 ##
 # TarReader reads tar files and allows iteration over their items
@@ -50,7 +52,14 @@ class Gem::Package::TarReader
     return enum_for __method__ unless block_given?
 
     until @io.eof? do
-      header = Gem::Package::TarHeader.from @io
+      begin
+        header = Gem::Package::TarHeader.from @io
+      rescue ArgumentError => e
+        # Specialize only exceptions from Gem::Package::TarHeader.strict_oct
+        raise e unless e.message.match?(/ is not an octal string$/)
+        raise Gem::Package::TarInvalidError, e.message
+      end
+
       return if header.empty?
       entry = Gem::Package::TarReader::Entry.new header, @io
       yield entry
@@ -58,7 +67,7 @@ class Gem::Package::TarReader
     end
   end
 
-  alias each_entry each
+  alias_method :each_entry, :each
 
   ##
   # NOTE: Do not call #rewind during #each
@@ -83,7 +92,7 @@ class Gem::Package::TarReader
 
     return unless found
 
-    return yield found
+    yield found
   ensure
     rewind
   end
