@@ -1,6 +1,7 @@
 # frozen_string_literal: true
-require 'rubygems/test_case'
-require 'rubygems/commands/check_command'
+
+require_relative "helper"
+require "rubygems/commands/check_command"
 
 class TestGemCommandsCheckCommand < Gem::TestCase
   def setup
@@ -45,23 +46,23 @@ class TestGemCommandsCheckCommand < Gem::TestCase
   end
 
   def test_doctor
-    gem 'a'
-    b = gem 'b'
+    gem "a"
+    b = gem "b"
 
     FileUtils.rm b.spec_file
 
-    assert_path_exists b.gem_dir
-    refute_path_exists b.spec_file
+    assert_path_exist b.gem_dir
+    assert_path_not_exist b.spec_file
 
     Gem.use_paths @gemhome
 
-    capture_io do
+    capture_output do
       use_ui @ui do
         @cmd.doctor
       end
     end
 
-    refute_path_exists b.gem_dir
-    refute_path_exists b.spec_file
+    assert_path_not_exist b.gem_dir
+    assert_path_not_exist b.spec_file
   end
 end
