@@ -79,7 +79,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_equal "Installing RubyGems 9", out.shift
     assert_equal "RubyGems system software updated", out.shift
 
@@ -123,7 +122,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_empty out
 
     err = @ui.error.split "\n"
@@ -132,6 +130,34 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     assert_empty err
   end
 
+  def test_execute_system_when_latest_does_not_support_your_ruby_but_previous_one_does
+    spec_fetcher do |fetcher|
+      fetcher.download "rubygems-update", 9 do |s|
+        s.files = %w[setup.rb]
+        s.required_ruby_version = "> 9"
+      end
+
+      fetcher.download "rubygems-update", 8 do |s|
+        s.files = %w[setup.rb]
+      end
+    end
+
+    @cmd.options[:args]          = []
+    @cmd.options[:system]        = true
+
+    use_ui @ui do
+      @cmd.execute
+    end
+
+    err = @ui.error.split "\n"
+    assert_empty err
+
+    out = @ui.output.split "\n"
+    assert_equal "Installing RubyGems 8", out.shift
+    assert_equal "RubyGems system software updated", out.shift
+    assert_empty out
+  end
+
   def test_execute_system_multiple
     spec_fetcher do |fetcher|
       fetcher.download "rubygems-update", 8 do |s|
@@ -151,7 +177,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_equal "Installing RubyGems 9", out.shift
     assert_equal "RubyGems system software updated", out.shift
 
@@ -185,7 +210,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_equal "Installing RubyGems 9", out.shift
     assert_equal "RubyGems system software updated", out.shift
 
@@ -193,7 +217,15 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
   end
 
   def test_execute_system_update_installed_in_non_default_gem_path
-    rubygems_update_spec = quick_gem "rubygems-update", 9 do |s|
+    rubygems_update_spec = Gem::Specification.new do |s|
+      s.name        = "rubygems-update"
+      s.version     = "9"
+      s.author      = "A User"
+      s.email       = "example@example.com"
+      s.homepage    = "http://example.com"
+      s.summary     = "this is a summary"
+      s.description = "This is a test description"
+
       write_file File.join(@tempdir, "setup.rb")
 
       s.files += %w[setup.rb]
@@ -205,7 +237,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
     gemhome2 = "#{@gemhome}2"
 
-    Gem::Installer.at(rubygems_update_package, :install_dir => gemhome2).install
+    Gem::Installer.at(rubygems_update_package, install_dir: gemhome2).install
 
     Gem.use_paths @gemhome, [gemhome2, @gemhome]
 
@@ -242,7 +274,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_equal "Installing RubyGems 8", out.shift
     assert_equal "RubyGems system software updated", out.shift
 
@@ -353,7 +384,6 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     end
 
     out = @ui.output.split "\n"
-    assert_equal "Updating rubygems-update", out.shift
     assert_equal "Installing RubyGems 9", out.shift
     assert_equal "RubyGems system software updated", out.shift
 
@@ -476,7 +506,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     a2 = @specs["a-2"]
 
     assert_path_exist File.join(a2.doc_dir, "rdoc")
-  end
+  end if defined?(Gem::RDoc) && !Gem.rdoc_hooks_defined_via_plugin?
 
   def test_execute_named
     spec_fetcher do |fetcher|
@@ -670,10 +700,10 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.handle_options %w[--system]
 
     expected = {
-      :args => [],
-      :document => %w[ri],
-      :force => false,
-      :system => true,
+      args: [],
+      document: %w[ri],
+      force: false,
+      system: true,
     }
 
     assert_equal expected, @cmd.options
@@ -689,10 +719,10 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.handle_options %w[--system 1.3.7]
 
     expected = {
-      :args => [],
-      :document => %w[ri],
-      :force => false,
-      :system => "1.3.7",
+      args: [],
+      document: %w[ri],
+      force: false,
+      system: "1.3.7",
     }
 
     assert_equal expected, @cmd.options
