@@ -1,28 +1,33 @@
 # frozen_string_literal: true
-require 'rubygems'
-require_relative 'helper'
-require 'rubygems/rdoc'
+
+require "rubygems"
+require_relative "helper"
+require "rubygems/rdoc"
 
 class TestGemRDoc < Gem::TestCase
-  Gem::RDoc.load_rdoc
-
   def setup
     super
 
-    @a = util_spec 'a' do |s|
+    @a = util_spec "a" do |s|
       s.rdoc_options = %w[--main MyTitle]
       s.extra_rdoc_files = %w[README]
     end
 
-    write_file File.join(@tempdir, 'lib', 'a.rb')
-    write_file File.join(@tempdir, 'README')
+    write_file File.join(@tempdir, "lib", "a.rb")
+    write_file File.join(@tempdir, "README")
 
     install_gem @a
 
-    @hook = Gem::RDoc.new @a
+    hook_class = if defined?(RDoc::RubyGemsHook)
+      RDoc::RubyGemsHook
+    else
+      Gem::RDoc
+    end
+
+    @hook = hook_class.new @a
 
     begin
-      Gem::RDoc.load_rdoc
+      hook_class.load_rdoc
     rescue Gem::DocumentError => e
       pend e.message
     end
@@ -70,14 +75,14 @@ class TestGemRDoc < Gem::TestCase
   def test_rdoc_installed?
     refute @hook.rdoc_installed?
 
-    FileUtils.mkdir_p @a.doc_dir 'rdoc'
+    FileUtils.mkdir_p @a.doc_dir "rdoc"
 
     assert @hook.rdoc_installed?
   end
 
   def test_remove
-    FileUtils.mkdir_p @a.doc_dir 'rdoc'
-    FileUtils.mkdir_p @a.doc_dir 'ri'
+    FileUtils.mkdir_p @a.doc_dir "rdoc"
+    FileUtils.mkdir_p @a.doc_dir "ri"
 
     @hook.remove
 
@@ -88,8 +93,8 @@ class TestGemRDoc < Gem::TestCase
   end
 
   def test_remove_unwritable
-    pend 'chmod not supported' if Gem.win_platform?
-    pend 'skipped in root privilege' if Process.uid.zero?
+    pend "chmod not supported" if Gem.win_platform?
+    pend "skipped in root privilege" if Process.uid.zero?
     FileUtils.mkdir_p @a.base_dir
     FileUtils.chmod 0, @a.base_dir
 
@@ -99,13 +104,13 @@ class TestGemRDoc < Gem::TestCase
 
     assert_equal @a.base_dir, e.directory
   ensure
-    FileUtils.chmod(0755, @a.base_dir) if File.directory?(@a.base_dir)
+    FileUtils.chmod(0o755, @a.base_dir) if File.directory?(@a.base_dir)
   end
 
   def test_ri_installed?
     refute @hook.ri_installed?
 
-    FileUtils.mkdir_p @a.doc_dir 'ri'
+    FileUtils.mkdir_p @a.doc_dir "ri"
 
     assert @hook.ri_installed?
   end
@@ -117,8 +122,8 @@ class TestGemRDoc < Gem::TestCase
   end
 
   def test_setup_unwritable
-    pend 'chmod not supported' if Gem.win_platform?
-    pend 'skipped in root privilege' if Process.uid.zero?
+    pend "chmod not supported" if Gem.win_platform?
+    pend "skipped in root privilege" if Process.uid.zero?
     FileUtils.mkdir_p @a.doc_dir
     FileUtils.chmod 0, @a.doc_dir
 
@@ -129,8 +134,8 @@ class TestGemRDoc < Gem::TestCase
     assert_equal @a.doc_dir, e.directory
   ensure
     if File.exist? @a.doc_dir
-      FileUtils.chmod 0755, @a.doc_dir
+      FileUtils.chmod 0o755, @a.doc_dir
       FileUtils.rm_r @a.doc_dir
     end
   end
-end
+end if defined?(Gem::RDoc)
