@@ -130,7 +130,7 @@ class TestGemRequire < Gem::TestCase
   end
 
   def test_dash_i_respects_default_library_extension_priority
-    pend "extensions don't quite work on jruby" if Gem.java_platform?
+    pend "needs investigation" if Gem.java_platform?
     pend "not installed yet" unless RbConfig::TOPDIR
 
     dash_i_ext_arg = util_install_extension_file("a")
@@ -182,6 +182,22 @@ class TestGemRequire < Gem::TestCase
     assert_equal %w[a-1 b-1], loaded_spec_names
   end
 
+  def test_require_is_not_lazy_with_shadowed_default_gem
+    b1_default = new_default_spec("b", "1", nil, "foo.rb")
+    install_default_gems b1_default
+
+    a1 = util_spec "a", "1", { "b" => ">= 1" }, "lib/test_gem_require_a.rb"
+    b1 = util_spec("b", "1", nil, "lib/foo.rb")
+    install_specs b1, a1
+
+    # Load default ruby gems fresh as if we've just started a ruby script.
+    Gem::Specification.reset
+
+    assert_require "test_gem_require_a"
+    assert_equal %w[a-1 b-1], loaded_spec_names
+    assert_equal unresolved_names, []
+  end
+
   def test_require_is_lazy_with_inexact_req
     a1 = util_spec "a", "1", { "b" => ">= 1" }, "lib/test_gem_require_a.rb"
     b1 = util_spec "b", "1", nil, "lib/b/c.rb"
@@ -223,9 +239,9 @@ class TestGemRequire < Gem::TestCase
 
   def test_activate_via_require_respects_loaded_files
     pend "Not sure what's going on. If another spec creates a 'a' gem before
-      this test, somehow require will load the benchmark in b, and ignore that the
+      this test, somehow require will load the erb in b, and ignore that the
       stdlib one is already in $LOADED_FEATURES?. Reproducible by running the
-      spaceship_specific_file test before this one" if java_platform?
+      spaceship_specific_file test before this one" if Gem.java_platform?
 
     pend "not installed yet" unless RbConfig::TOPDIR
 
@@ -240,11 +256,11 @@ class TestGemRequire < Gem::TestCase
       load_path_changed = true
     end
 
-    require "benchmark" # the stdlib
+    require "erb" # the stdlib
 
     a1 = util_spec "a", "1", { "b" => ">= 1" }, "lib/test_gem_require_a.rb"
-    b1 = util_spec "b", "1", nil, "lib/benchmark.rb"
-    b2 = util_spec "b", "2", nil, "lib/benchmark.rb"
+    b1 = util_spec "b", "1", nil, "lib/erb.rb"
+    b2 = util_spec "b", "2", nil, "lib/erb.rb"
 
     install_specs b1, b2, a1
 
@@ -257,12 +273,12 @@ class TestGemRequire < Gem::TestCase
 
     assert_equal unresolved_names, ["b (>= 1)"]
 
-    # The require('benchmark') below will activate b-2. However, its
-    # lib/benchmark.rb won't ever be loaded. The reason is MRI sees that even
-    # though b-2 is earlier in $LOAD_PATH it already loaded a benchmark.rb file
+    # The require('erb') below will activate b-2. However, its
+    # lib/erb.rb won't ever be loaded. The reason is MRI sees that even
+    # though b-2 is earlier in $LOAD_PATH it already loaded a erb.rb file
     # and that still exists in $LOAD_PATH (further down),
     # and as a result #gem_original_require returns false.
-    refute require("benchmark"), "the benchmark stdlib should be recognized as already loaded"
+    refute require("erb"), "the erb stdlib should be recognized as already loaded"
 
     assert_includes $LOAD_PATH, b2.full_require_paths[0]
     assert_includes $LOAD_PATH, rubylibdir
@@ -273,7 +289,7 @@ class TestGemRequire < Gem::TestCase
     assert_operator $LOAD_PATH.index(b2.full_require_paths[0]), :<, $LOAD_PATH.index(rubylibdir), message
 
     # We detected that we should activate b-2, so we did so, but
-    # then #gem_original_require decided "I've already got some benchmark.rb" loaded.
+    # then #gem_original_require decided "I've already got some erb.rb" loaded.
     # This case is fine because our lazy loading provided exactly
     # the same behavior as eager loading would have.
 
@@ -382,8 +398,8 @@ class TestGemRequire < Gem::TestCase
 
     # Remove an old default gem version directly from disk as if someone ran
     # gem cleanup.
-    FileUtils.rm_rf(File.join @gemhome, "#{b1.full_name}")
-    FileUtils.rm_rf(File.join @gemhome, "specifications", "default", "#{b1.full_name}.gemspec")
+    FileUtils.rm_rf(File.join(@gemhome, b1.full_name.to_s))
+    FileUtils.rm_rf(File.join(@gemhome, "specifications", "default", "#{b1.full_name}.gemspec"))
 
     # Require gems that have not been removed.
     assert_require "a/b"
@@ -424,7 +440,7 @@ class TestGemRequire < Gem::TestCase
 
     times_called = 0
 
-    Kernel.stub(:gem, ->(name, requirement) { times_called += 1 }) do
+    Kernel.stub(:gem, ->(_name, _requirement) { times_called += 1 }) do
       refute_require "default/gem"
     end
 
@@ -471,11 +487,11 @@ class TestGemRequire < Gem::TestCase
     File.write(path, code)
 
     output = Gem::Util.popen({ "GEM_HOME" => @gemhome }, *ruby_with_rubygems_in_load_path, path).strip
-    assert $?.success?
     refute_empty output
     assert_equal "999.99.9", output.lines[0].chomp
     # Make sure only files from the newer json gem are loaded, and no files from the default json gem
     assert_equal ["#{@gemhome}/gems/json-999.99.9/lib/json.rb"], output.lines.grep(%r{/gems/json-}).map(&:chomp)
+    assert $?.success?
   end
 
   def test_default_gem_and_normal_gem
@@ -489,6 +505,33 @@ class TestGemRequire < Gem::TestCase
     assert_equal %w[default-3.0], loaded_spec_names
   end
 
+  def test_default_gem_and_normal_gem_same_version
+    default_gem_spec = new_default_spec("default", "3.0",
+                                        nil, "default/gem.rb")
+    install_default_gems(default_gem_spec)
+    normal_gem_spec = util_spec("default", "3.0", nil,
+                               "lib/default/gem.rb")
+    install_specs(normal_gem_spec)
+
+    # Load default ruby gems fresh as if we've just started a ruby script.
+    Gem::Specification.reset
+
+    assert_require "default/gem"
+    assert_equal %w[default-3.0], loaded_spec_names
+    refute Gem.loaded_specs["default"].default_gem?
+  end
+
+  def test_normal_gem_does_not_shadow_default_gem
+    default_gem_spec = new_default_spec("foo", "2.0", nil, "foo.rb")
+    install_default_gems(default_gem_spec)
+
+    normal_gem_spec = util_spec("fake-foo", "3.0", nil, "lib/foo.rb")
+    install_specs(normal_gem_spec)
+
+    assert_require "foo"
+    assert_equal %w[foo-2.0], loaded_spec_names
+  end
+
   def test_normal_gems_with_overridden_load_error_message
     normal_gem_spec = util_spec("normal", "3.0", nil, "lib/normal/gem.rb")
 
@@ -529,6 +572,65 @@ class TestGemRequire < Gem::TestCase
     assert_equal %w[default-3.0.0.rc2], loaded_spec_names
   end
 
+  def test_default_gem_with_unresolved_gems_depending_on_it
+    my_http_old = util_spec "my-http", "0.1.1", nil, "lib/my/http.rb"
+    install_gem my_http_old
+
+    my_http_default = new_default_spec "my-http", "0.3.0", nil, "my/http.rb"
+    install_default_gems my_http_default
+
+    faraday_1 = util_spec "faraday", "1", { "my-http" => ">= 0" }
+    install_gem faraday_1
+
+    faraday_2 = util_spec "faraday", "2", { "my-http" => ">= 0" }
+    install_gem faraday_2
+
+    chef = util_spec "chef", "1", { "faraday" => [">= 1", "< 3"] }, "lib/chef.rb"
+    install_gem chef
+
+    assert_require "chef"
+    assert_require "my/http"
+  end
+
+  def test_default_gem_required_circulary_with_unresolved_gems_depending_on_it
+    my_http_old = util_spec "my-http", "0.1.1", nil, "lib/my/http.rb"
+    install_gem my_http_old
+
+    my_http_default = new_default_spec "my-http", "0.3.0", nil, "my/http.rb"
+    my_http_default_path = File.join(@tempdir, "default_gems", "lib", "my/http.rb")
+    install_default_gems my_http_default
+    File.write(my_http_default_path, 'require "my/http"')
+
+    faraday_1 = util_spec "faraday", "1", { "my-http" => ">= 0" }
+    install_gem faraday_1
+
+    faraday_2 = util_spec "faraday", "2", { "my-http" => ">= 0" }
+    install_gem faraday_2
+
+    chef = util_spec "chef", "1", { "faraday" => [">= 1", "< 3"] }, "lib/chef.rb"
+    install_gem chef
+
+    assert_require "chef"
+
+    out, err = capture_output do
+      assert_require "my/http"
+    end
+
+    assert_empty out
+
+    circular_require_warning = false
+
+    err_lines = err.split("\n").reject do |line|
+      if line.include?("circular require")
+        circular_require_warning = true
+      elsif circular_require_warning # ignore backtrace lines for circular require warning
+        circular_require_warning = line.start_with?(/[\s]/)
+      end
+    end
+
+    assert_empty err_lines
+  end
+
   def loaded_spec_names
     Gem.loaded_specs.values.map(&:full_name).sort
   end
@@ -540,8 +642,10 @@ class TestGemRequire < Gem::TestCase
   def test_try_activate_error_unlocks_require_monitor
     silence_warnings do
       class << ::Gem
-        alias old_try_activate try_activate
-        def try_activate(*); raise "raised from try_activate"; end
+        alias_method :old_try_activate, :try_activate
+        def try_activate(*)
+          raise "raised from try_activate"
+        end
       end
     end
 
@@ -552,7 +656,7 @@ class TestGemRequire < Gem::TestCase
   ensure
     silence_warnings do
       class << ::Gem
-        alias try_activate old_try_activate
+        alias_method :try_activate, :old_try_activate
       end
     end
     Kernel::RUBYGEMS_ACTIVATION_MONITOR.exit
@@ -617,11 +721,11 @@ class TestGemRequire < Gem::TestCase
         _, err = capture_subprocess_io do
           system(*ruby_with_rubygems_in_load_path, "-w", "--disable=gems", "-C", dir, "main.rb")
         end
-        assert_match(/{:x=>1}\n{:y=>2}\n$/, err)
+        assert_match(/#{{ x: 1 }.inspect}\n#{{ y: 2 }.inspect}\n$/, err)
         _, err = capture_subprocess_io do
           system(*ruby_with_rubygems_in_load_path, "-w", "--enable=gems", "-C", dir, "main.rb")
         end
-        assert_match(/{:x=>1}\n{:y=>2}\n$/, err)
+        assert_match(/#{{ x: 1 }.inspect}\n#{{ y: 2 }.inspect}\n$/, err)
       end
     end
   end
